@@ -355,9 +355,14 @@ class ABBAbase:
         series - list
             Reconstruction of the time series.
         """
-        
+        if type(strings) != str:
+            strings = "".join(strings)
+            
         if parameters is None:
-            series = inv_transform(strings, self.parameters.centers, self.parameters.hashm, start) 
+            try:
+                series = inv_transform(strings, self.parameters.centers, self.parameters.hashm, start) 
+            except:
+                raise ValueError("Please train the model using ``fit_transform`` first.")
         else:
             series = inv_transform(strings, parameters.centers, parameters.hashm, start) 
         return series
@@ -754,7 +759,10 @@ class fabba_model(Aggregation2D, ABBAbase):
         if type(strings) != str:
             strings = "".join(strings)
         if parameters is None:
-            series = inv_transform(strings, self.parameters.centers, self.parameters.hashm, start) 
+            try:
+                series = inv_transform(strings, self.parameters.centers, self.parameters.hashm, start) 
+            except:
+                raise ValueError("Please train the model using ``fit_transform`` first.") 
         else:
             series = inv_transform(strings, parameters.centers, parameters.hashm, start) 
     
